@@ -304,6 +304,23 @@ class Realtime():
                     if btk_type in constants.NAMED_TROPICAL_STORM_TYPES:
                         self.data[stormid]['ace'] += np.round(ace,4)
 
+            #Determine storm name for invests
+            if invest_bool == True:
+                
+                #Determine letter in front of invest
+                add_letter = 'L'
+                if stormid[0] == 'C':
+                    add_letter = 'C'
+                elif stormid[0] == 'E':
+                    add_letter = 'E'
+                elif stormid[0] == 'W':
+                    add_letter = 'W'
+                elif stormid[0] == 'I':
+                    add_letter = 'I'
+                elif stormid[0] == 'S':
+                    add_letter = 'S'
+                name = stormid[2:4] + add_letter
+            
             #Add storm name
             self.data[stormid]['name'] = name
             
@@ -334,7 +351,7 @@ class Realtime():
 
         #Get relevant filenames from directory
         files = []
-        search_pattern = f'b[isw][ohp][01234][0123456789]{current_year}.dat'
+        search_pattern = f'b[isw][ohp][012349][0123456789]{current_year}.dat'
 
         pattern = re.compile(search_pattern)
         filelist = pattern.findall(string)
@@ -342,18 +359,35 @@ class Realtime():
             if filename not in files: files.append(filename)
         
         #Search for following year (for SH storms)
-        search_pattern = f'b[isw][ohp][01234][0123456789]{current_year+1}.dat'
+        search_pattern = f'b[isw][ohp][012349][0123456789]{current_year+1}.dat'
 
         pattern = re.compile(search_pattern)
         filelist = pattern.findall(string)
         for filename in filelist:
             if filename not in files: files.append(filename)
+        
+        if source in ['jtwc','ucar']:
+            try:
+                urlpath_nextyear = urllib.request.urlopen(url.replace(str(current_year),str(current_year+1)))
+                string_nextyear = urlpath_nextyear.read().decode('utf-8')
+
+                pattern = re.compile(search_pattern)
+                filelist = pattern.findall(string_nextyear)
+                for filename in filelist:
+                    if filename not in files: files.append(filename)
+            except:
+                pass
 
         #For each file, read in file content and add to hurdat dict
         for file in files:
 
             #Get file ID
             stormid = ((file.split(".dat")[0])[1:]).upper()
+            
+            #Check for invest status
+            invest_bool = False
+            if int(stormid[2]) == 9:
+                invest_bool = True
 
             #Determine basin based on where storm developed
             add_basin = 'west_pacific'
@@ -363,7 +397,7 @@ class Realtime():
                 add_basin = ''
 
             #add empty entry into dict
-            self.data[stormid] = {'id':stormid,'operational_id':stormid,'name':'','year':int(stormid[4:8]),'season':int(stormid[4:8]),'basin':add_basin,'source_info':'Joint Typhoon Warning Center','realtime':True,'invest':False}
+            self.data[stormid] = {'id':stormid,'operational_id':stormid,'name':'','year':int(stormid[4:8]),'season':int(stormid[4:8]),'basin':add_basin,'source_info':'Joint Typhoon Warning Center','realtime':True,'invest':invest_bool}
             self.data[stormid]['source'] = 'jtwc'
             
             #Add source info
@@ -385,6 +419,7 @@ class Realtime():
             url = f"https://www.nrlmry.navy.mil/atcf_web/docs/tracks/{current_year}/{file}"
             if source == 'noaa': url = f"https://www.ssd.noaa.gov/PS/TROP/DATA/ATCF/JTWC/{file}"
             if source == 'ucar': url = f"http://hurricanes.ral.ucar.edu/repository/data/bdecks_open/{current_year}/{file}"
+            if f"{current_year+1}.dat" in url: url = url.replace(str(current_year),str(current_year+1))
             f = urllib.request.urlopen(url)
             content = f.read()
             content = content.decode("utf-8")
@@ -460,6 +495,23 @@ class Realtime():
                     if btk_type in constants.NAMED_TROPICAL_STORM_TYPES:
                         self.data[stormid]['ace'] += np.round(ace,4)
 
+            #Determine storm name for invests
+            if invest_bool == True:
+                
+                #Determine letter in front of invest
+                add_letter = 'L'
+                if stormid[0] == 'C':
+                    add_letter = 'C'
+                elif stormid[0] == 'E':
+                    add_letter = 'E'
+                elif stormid[0] == 'W':
+                    add_letter = 'W'
+                elif stormid[0] == 'I':
+                    add_letter = 'I'
+                elif stormid[0] == 'S':
+                    add_letter = 'S'
+                name = stormid[2:4] + add_letter
+            
             #Add storm name
             self.data[stormid]['name'] = name
             
